@@ -175,10 +175,10 @@ class OrderView(DetailView):
         if order.id != session_order.id:
             raise Http404
             
-        # try:
-        #     del self.request.session['order']
-        # except KeyError:
-        #     pass
+        try:
+            del self.request.session['order']
+        except KeyError:
+            pass
 
         return result
 
